==> eiciel-0.4.1.tar.bz2: eiciel-0.4.1/src/eiciel_main_window.hpp <==
#ifndef EICIEL_MAIN_WINDOW_HPP
#define EICIEL_MAIN_WINDOW_HPP

#include <config.hpp>
#include <string>
#include <gtkmm.h>
#include <gettext.h>
#include "llista_acl.hpp"
#include "llista_participant.hpp"
#include "eiciel_main_controler.hpp"
#include "tipus_element_acl.hpp"

using namespace std;

class EicielMainControler;


class EicielWindow : public Gtk::VBox 
{
	public:
		EicielWindow(EicielMainControler* cont);
		void afegeixNoSeleccionable(string titol, bool lectura, bool escriptura, bool execucio, TipusElement e);
		void afegeixSeleccionable(string titol, bool lectura, bool escriptura, bool execucio, TipusElement e);
		void buidaLlistaACL();
		void establirNomFitxer(string nomFitxer);
		void activarBotoDefaultACL(bool b);
		void hiHaDefaultACL(bool b);
		bool donaACLDefault();

        void inicialitzar(string s);
		bool fitxerObert();

		void activacio(bool b);

		Glib::ustring ultimError();
		virtual ~EicielWindow();

	private:
		// Gtk::Button obrirFitxer;
		// Gtk::HBox zona_superior;
		Gtk::VBox zona_principal;
		Gtk::VBox marc_inferior;
        
		Glib::RefPtr<Gtk::ListStore> refLlistaACL;
		Gtk::ScrolledWindow contenidorVistaLlistaACL;
		Gtk::TreeView vistaLlistaACL;
        
        Glib::RefPtr<Gtk::ListStore> refLlistaParticipants;
        Gtk::ScrolledWindow contenidorVistaLlistaParticipants;
        Gtk::TreeView vistaLlistaParticipants;
        
        Gtk::HBox selector_participant;
		Gtk::RadioButton_Helpers::Group tipusACL;
		Gtk::RadioButton ACLusuari;
		Gtk::RadioButton ACLgrup;
        Gtk::CheckButton aclDefault;
		Gtk::ToggleButton modificarACLDefault;

		Gtk::VButtonBox botonera_dreta;
		// Gtk::HButtonBox botonera_inferior;
		Gtk::HButtonBox botonera_mig;
		Gtk::Button afegirACL;
		//Gtk::CheckButton modificarACLDefault;
		Gtk::Button eliminarACL;
		// Gtk::Label nomFitxer;
		Gtk::Button quantA;
		Gtk::Button ajuda;
		EicielMainControler* controlador;
		Gtk::Button sortir;

		Glib::RefPtr<Gdk::Pixbuf> iconaUsuari;
		Glib::RefPtr<Gdk::Pixbuf> iconaGrup;
		Glib::RefPtr<Gdk::Pixbuf> iconaAltres;
		Glib::RefPtr<Gdk::Pixbuf> iconaMascara;

		Glib::RefPtr<Gdk::Pixbuf> iconaUsuariACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaGrupACL;

		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultUsuari;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultGrup;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultAltres;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultUsuariACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultGrupACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultMascara;

		ModelLlistaACL modelLlistaACL;
        ModelLlistaParticipant modelLlistaParticipant;

		void noHiHaFitxer();
		void canviDeSeleccioACL();
		void hiHaSeleccioACL();
		void noHiHaSeleccioACL();

		void canviDeSeleccioParticipant();
		void hiHaSeleccioParticipant();
		void noHiHaSeleccioParticipant();
		bool funcioSeleccioACL(const Glib::RefPtr<Gtk::TreeModel>& model,
				const Gtk::TreeModel::Path& path, bool);
		Glib::RefPtr<Gdk::Pixbuf> retornaIconaApropiada(TipusElement e);
		void afegeixElement(string titol, bool lectura, bool escriptura, bool execucio,
				TipusElement e, Gtk::TreeModel::Row& row);
		void eliminarACLSeleccionada();
		void afegirParticipantSeleccionat();
		void canviPermisos(const Glib::ustring& cadena);

        void emplenarUsuaris();
        void emplenarGrups();
};

#endif

==> eiciel-0.5.0.tar.bz2: eiciel-0.5.0/src/eiciel_main_window.hpp <==
/*
    Eiciel - GNOME editor of ACL file permissions.
    Copyright (C) 2004-2005 Roger Ferrer Ibez

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef EICIEL_MAIN_WINDOW_HPP
#define EICIEL_MAIN_WINDOW_HPP

#include <config.hpp>
#include <string>
#include <gtkmm.h>
#include <gettext.h>
#include "llista_acl.hpp"
#include "llista_participant.hpp"
#include "eiciel_main_controler.hpp"
#include "tipus_element_acl.hpp"

using namespace std;

class EicielMainControler;


class EicielWindow : public Gtk::VBox 
{
	public:
		EicielWindow(EicielMainControler* cont);
		void afegeixNoSeleccionable(string titol, bool lectura, bool escriptura, bool execucio, TipusElement e,
				bool efectiuLectura = true, bool efectiuEscriptura = true, bool efectiuExecucio = true);
		void afegeixSeleccionable(string titol, bool lectura, bool escriptura, bool execucio, TipusElement e,
				bool efectiuLectura = true, bool efectiuEscriptura = true, bool efectiuExecucio = true);
		void buidaLlistaACL();
		void establirNomFitxer(string nomFitxer);
		void activarBotoDefaultACL(bool b);
		void hiHaDefaultACL(bool b);
		bool donaACLDefault();

        void inicialitzar(string s);
		bool fitxerObert();

		void activacio(bool b);

		void mostrarAdmiracio(bool b);

		Glib::ustring ultimError();
		virtual ~EicielWindow();

	private:
		Gtk::VBox zona_principal;
		Gtk::VBox marc_inferior;
        
		Glib::RefPtr<Gtk::ListStore> refLlistaACL;
		Gtk::ScrolledWindow contenidorVistaLlistaACL;
		Gtk::TreeView vistaLlistaACL;
        
        Glib::RefPtr<Gtk::ListStore> refLlistaParticipants;
        Gtk::ScrolledWindow contenidorVistaLlistaParticipants;
        Gtk::TreeView vistaLlistaParticipants;
        
        Gtk::HBox selector_participant;
		Gtk::RadioButton_Helpers::Group tipusACL;
		Gtk::RadioButton ACLusuari;
		Gtk::RadioButton ACLgrup;
        Gtk::CheckButton aclDefault;
		Gtk::ToggleButton modificarACLDefault;

		Gtk::VButtonBox botonera_dreta;
		Gtk::HButtonBox botonera_mig;
		Gtk::Button afegirACL;
		Gtk::Button eliminarACL;
		EicielMainControler* controlador;

		Glib::RefPtr<Gdk::Pixbuf> iconaUsuari;
		Glib::RefPtr<Gdk::Pixbuf> iconaGrup;
		Glib::RefPtr<Gdk::Pixbuf> iconaAltres;
		Glib::RefPtr<Gdk::Pixbuf> iconaMascara;

		Glib::RefPtr<Gdk::Pixbuf> iconaUsuariACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaGrupACL;

		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultUsuari;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultGrup;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultAltres;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultUsuariACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultGrupACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultMascara;
		
		Gtk::Label llegendaInferior;

		ModelLlistaACL modelLlistaACL;
        ModelLlistaParticipant modelLlistaParticipant;

		void noHiHaFitxer();
		void canviDeSeleccioACL();
		void hiHaSeleccioACL();
		void noHiHaSeleccioACL();

		void canviDeSeleccioParticipant();
		void hiHaSeleccioParticipant();
		void noHiHaSeleccioParticipant();
		bool funcioSeleccioACL(const Glib::RefPtr<Gtk::TreeModel>& model,
				const Gtk::TreeModel::Path& path, bool);
		Glib::RefPtr<Gdk::Pixbuf> retornaIconaApropiada(TipusElement e);
		void afegeixElement(string titol, bool lectura, bool escriptura, bool execucio,
				TipusElement e, Gtk::TreeModel::Row& row,
				bool efectiuLectura, bool efectiuEscriptura, bool efectiuExecucio);
		void eliminarACLSeleccionada();
		void afegirParticipantSeleccionat();
		void canviPermisos(const Glib::ustring& cadena, TipusPermis p);

        void emplenarUsuaris();
        void emplenarGrups();
};

#endif
